#!/bin/bash
echo "Beginning Elasticsearch bootstrap"
ELASTIC_SEARCH_URL="http://localhost:9200"

#For the moment, this just calls echo. Can be enhanced later
log(){
	echo; echo "$1"
}

errorExit() {
    echo; echo -e "\033[31mERROR:\033[0m $1"; echo
    exit 1
}

elasticSearchIsNotReady(){
	#echo "in method isElasticSearchReady"
	curl "$ELASTIC_SEARCH_URL" > /dev/null 2>&1
	if [ $? -ne 0 ]; then
		return 0
	else
		return 1
	fi
}

setElasticSearchParams() {
	log "Waiting for elastic search to get ready"
	while elasticSearchIsNotReady
	do
			sleep 5
			echo -n '.'
	done
	log "Elastic search is ready. Executing commands"
	curlresponse=$(curl --silent -XGET "$ELASTIC_SEARCH_URL/_alias/active_insight_data") 
	#echo "Elastic search curl response: $curlresponse"
	if [[ $curlresponse = *missing* ]]; then
	    log "Running alias creation"
	    curl -X PUT "$ELASTIC_SEARCH_URL/_template/active_insight_data" -H "Content-Type: application/json" -d '{"template": "active_insight_data_*","aliases": {"active_insight_data":  {},"search_insight_data": {}},"mappings":{"repo_storage_info":{"properties":{"used_space":{"type":"double"},"timestamp":{"type":"date"}}},"storage_summary_info":{"properties":{"used_space":{"type":"double"},"artifacts_size":{"type":"double"},"timestamp":{"type":"date"}}}}}' --user $ELASTIC_SEARCH_USERNAME:$ELASTIC_SEARCH_PASSWORD > /dev/null 2>&1 || errorExit "could not update Elastic Search container"
	    curl -X PUT "$ELASTIC_SEARCH_URL/%3Cactive_insight_data_%7Bnow%2Fd%7D-1%3E" --user $ELASTIC_SEARCH_USERNAME:$ELASTIC_SEARCH_PASSWORD > /dev/null 2>&1 || errorExit "could not update Elastic Search container"
	else 
		templatedetails=$(curl --silent -XGET "$ELASTIC_SEARCH_URL/_template/active_insight_data" --user $ELASTIC_SEARCH_USERNAME:$ELASTIC_SEARCH_PASSWORD ) 
		
		if [[ $templatedetails != *double* ]]; then
			updatetemplate
		fi	
	fi		
}

updatetemplate(){
	log "Updating template" 
    curl -X PUT "$ELASTIC_SEARCH_URL/_template/active_insight_data" -H "Content-Type: application/json" -d '{"template": "active_insight_data_*","aliases": {"active_insight_data":  {},"search_insight_data": {}},"mappings":{"repo_storage_info":{"properties":{"used_space":{"type":"double"},"timestamp":{"type":"date"}}},"storage_summary_info":{"properties":{"used_space":{"type":"double"},"artifacts_size":{"type":"double"},"timestamp":{"type":"date"}}}}}' --user $ELASTIC_SEARCH_USERNAME:$ELASTIC_SEARCH_PASSWORD > /dev/null 2>&1 || errorExit "could not update Elastic Search container"
    log "Updated template" 
    indexnamedetails=$(curl --silent -XGET "$ELASTIC_SEARCH_URL/_alias/active_insight_data" --user $ELASTIC_SEARCH_USERNAME:$ELASTIC_SEARCH_PASSWORD) 
    indexname=$(echo $indexnamedetails |cut -d'"' -f 2)
   	log "Old index $indexname"
    curl -X PUT "$ELASTIC_SEARCH_URL/%3Cactive_insight_data_%7Bnow%2Fd%7D-1%3E" --user $ELASTIC_SEARCH_USERNAME:$ELASTIC_SEARCH_PASSWORD > /dev/null 2>&1 || errorExit "could not update Elastic Search container"
    log "Created new index" 
    aliasdetails=$(curl --silent -XGET "$ELASTIC_SEARCH_URL/_alias/active_insight_data") 
    log $aliasdetails
    curl -X POST "$ELASTIC_SEARCH_URL/_aliases" -H "Content-Type: application/json" -d '{"actions":[{"remove":{"index":'\""$indexname"\"',"alias":"active_insight_data"}}]}' --user $ELASTIC_SEARCH_USERNAME:$ELASTIC_SEARCH_PASSWORD > /dev/null 2>&1 || errorExit "could not remove index from alias"
    log "Removed the old index from active alias"
}
setElasticSearchParams