#!/bin/bash

errorExit() {
    echo; echo -e "\033[31mERROR:\033[0m $1"; echo
    exit 1
}

log () {
    echo; echo $1;
}

mongoIsNotReady() {
	mongo --version > /dev/null 2>&1
    outcome1=$?
    ss -lntu | grep -wq "27017"  2>&1
    outcome2=$?
    if [[ $outcome1 -eq 0 ]] && [[ $outcome2 -eq 0  ]]; then
        return 0
    else
        return 1
    fi
}

createMongoData() {
    #If this code has already been run once, take the original file
    if [ ! -f $MONGO_PATH/createMongoUsers.js.backup ]; then
        cp $MONGO_PATH/createMongoUsers.js $MONGO_PATH/createMongoUsers.js.backup
    else 
        cp $MONGO_PATH/createMongoUsers.js.backup $MONGO_PATH/createMongoUsers.js
    fi

    log "Waiting for MongoDB to get ready"
    while ! mongoIsNotReady
    do
            sleep 5
            echo -n '.'
    done
    log "MongoDB is ready. Executing commands"

    ## Find out the credentials for Mongo
    local ADMIN_USER="admin"
    local ADMIN_PWD="password"
    local EMPTY_MONGO="yes"

    if [ ! -z $LOCAL_MONGO ]; then
        EMPTY_MONGO="no"
        choice="na"
        default_choice="y"
        #TODO maybe we should also ask if this is a fresh db
        until [[ "${choice}" == "y" || "${choice}" == "n" || "${choice}" == "Y" || "${choice}" == "N" ]]; do
            echo;echo;
            read -p "Is this a fresh installation with no users? (If you choose 'y', the installer will create an admin user) [Y/n]: " choice
            : ${choice:=$default_choice}
        done
        if [[ $choice == "y" || $choice == "Y" ]]; then
            EMPTY_MONGO="yes"
        fi
        if [ $LOCAL_MONGO == "yes" ]; then
            log "Please enter the Mongo admin user ID"
            echo; echo;
            read -p "Please enter the Mongo admin user ID [$ADMIN_USER] : " choice
            : ${choice:=$ADMIN_USER}
            ADMIN_USER=$choice
            log "Please enter the Mongo admin user password"
            echo; echo;
            read -p "Please enter the Mongo admin user password [$ADMIN_PWD] : " choice
            : ${choice:=$ADMIN_PWD}
            ADMIN_PWD=$choice
        fi
    fi

    sed -i "s/__EMPTY_DB__/$EMPTY_MONGO/g" $MONGO_PATH/createMongoUsers.js
    sed -i "s/__ADMIN_USER__/$ADMIN_USER/g" $MONGO_PATH/createMongoUsers.js
    sed -i "s/__ADMIN_USER_PWD__/$ADMIN_PWD/g" $MONGO_PATH/createMongoUsers.js
    
    mongo admin $MONGO_PATH/createMongoUsers.js

    if [ $? -ne 0 ]; then
        log "Mongo DB seeding was unsuccessful. This could happen because of wrong credentials or because the data already exists. \
Choose Y to try again, N to abort and S to skip"
        choice="na"
        default_choice="y"
        until [[ "${choice}" == "y" || "${choice}" == "n" || "${choice}" == "Y" || "${choice}" == "N" || "${choice}" == "S" || "${choice}" == "s" ]]; do
            echo;echo;
            read -p "Would you like to try again? [Y/n ]: " choice
            : ${choice:=$default_choice}
        done
        if [[ $choice == "n" || $choice == "N" ]]; then
            exit 1
        elif  [[ $choice == "y" || $choice == "Y" ]]; then
            createMongoData
        fi
    fi
}

createMongoData
